@@ -3,11 +3,13 @@ from .normal import NormalDataTest
 from .delta_lognormal import DeltaLognormalDataTest
 from .discrete import DiscreteDataTest
 from .poisson import PoissonDataTest
+from .delta_normal import DeltaNormalDataTest
 
 __all__ = [
     "BinaryDataTest",
     "NormalDataTest",
     "DeltaLognormalDataTest",
+    "DeltaNormalDataTest",
     "DiscreteDataTest",
     "PoissonDataTest",
 ]
