@@ -4,12 +4,14 @@ from .evaluation import (
     eval_delta_lognormal_agg,
     eval_numerical_dirichlet_agg,
     eval_poisson_agg,
+    eval_delta_normal_agg,
 )
 
 __all__ = [
     "eval_bernoulli_agg",
     "eval_normal_agg",
     "eval_delta_lognormal_agg",
+    "eval_delta_normal_agg",
     "eval_numerical_dirichlet_agg",
     "eval_poisson_agg",
 ]
